[Libreoffice-commits] core.git: 3 commits - sw/qa sw/source writerfilter/source

Miklos Vajna vmiklos at collabora.co.uk
Sat Mar 14 08:08:41 PDT 2015


 dev/null                                      |binary
 sw/qa/extras/uiwriter/data/tdf90003.odt       |binary
 sw/qa/extras/uiwriter/uiwriter.cxx            |   23 +--
 sw/source/core/text/itrform2.cxx              |    7 
 sw/source/uibase/inc/wrtsh.hxx                |  110 +++++++-------
 sw/source/uibase/wrtsh/move.cxx               |  108 +++++++-------
 sw/source/uibase/wrtsh/select.cxx             |  196 +++++++++++++-------------
 sw/source/uibase/wrtsh/wrtsh1.cxx             |   58 +++----
 sw/source/uibase/wrtsh/wrtsh2.cxx             |    8 -
 sw/source/uibase/wrtsh/wrtsh3.cxx             |   18 +-
 sw/source/uibase/wrtsh/wrtundo.cxx            |    4 
 writerfilter/source/dmapper/SettingsTable.cxx |   26 +--
 12 files changed, 275 insertions(+), 283 deletions(-)

New commits:
commit bcefd5cda926f86db16b1bcf6838431b5b0d61b5
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date:   Sat Mar 14 15:55:40 2015 +0100

    SwWrtShell: rename member variables missing their prefixes
    
    Change-Id: I78ae647cca9167e130592fd11b8dd15c512a2353

diff --git a/sw/source/uibase/wrtsh/select.cxx b/sw/source/uibase/wrtsh/select.cxx
index 565dbf3..439c945 100644
--- a/sw/source/uibase/wrtsh/select.cxx
+++ b/sw/source/uibase/wrtsh/select.cxx
@@ -81,9 +81,9 @@ bool SwWrtShell::SelWrd(const Point *pPt, bool )
     EndSelect();
     if( bRet )
     {
-        bSelWrd = true;
+        m_bSelWrd = true;
         if(pPt)
-            aStart = *pPt;
+            m_aStart = *pPt;
     }
     return bRet;
 }
@@ -99,9 +99,9 @@ void SwWrtShell::SelSentence(const Point *pPt, bool )
     }
     EndSelect();
     if(pPt)
-        aStart = *pPt;
-    bSelLn = true;
-    bSelWrd = false;  // disable SelWord, otherwise no SelLine goes on
+        m_aStart = *pPt;
+    m_bSelLn = true;
+    m_bSelWrd = false;  // disable SelWord, otherwise no SelLine goes on
 }
 
 void SwWrtShell::SelPara(const Point *pPt, bool )
@@ -115,9 +115,9 @@ void SwWrtShell::SelPara(const Point *pPt, bool )
     }
     EndSelect();
     if(pPt)
-        aStart = *pPt;
-    bSelLn = false;
-    bSelWrd = false;  // disable SelWord, otherwise no SelLine goes on
+        m_aStart = *pPt;
+    m_bSelLn = false;
+    m_bSelWrd = false;  // disable SelWord, otherwise no SelLine goes on
 }
 
 long SwWrtShell::SelAll()
@@ -125,7 +125,7 @@ long SwWrtShell::SelAll()
     const bool bLockedView = IsViewLocked();
     LockView( true );
     {
-        if(bBlockMode)
+        if(m_bBlockMode)
             LeaveBlockMode();
         SwMvContext aMvContext(this);
         bool bMoveTable = false;
@@ -279,25 +279,25 @@ sal_uLong SwWrtShell::SearchAttr( const SfxItemSet& rFindSet, bool bNoColls,
 
 void SwWrtShell::PushMode()
 {
-    pModeStack = new ModeStack( pModeStack, bIns, bExtMode, bAddMode, bBlockMode );
+    m_pModeStack = new ModeStack( m_pModeStack, m_bIns, m_bExtMode, m_bAddMode, m_bBlockMode );
 }
 
 void SwWrtShell::PopMode()
 {
-    if ( 0 == pModeStack )
+    if ( 0 == m_pModeStack )
         return;
 
-    if ( bExtMode && !pModeStack->bExt )
+    if ( m_bExtMode && !m_pModeStack->bExt )
         LeaveExtMode();
-    if ( bAddMode && !pModeStack->bAdd )
+    if ( m_bAddMode && !m_pModeStack->bAdd )
         LeaveAddMode();
-    if ( bBlockMode && !pModeStack->bBlock )
+    if ( m_bBlockMode && !m_pModeStack->bBlock )
         LeaveBlockMode();
-    bIns = pModeStack->bIns;
+    m_bIns = m_pModeStack->bIns;
 
-    ModeStack *pTmp = pModeStack->pNext;
-    delete pModeStack;
-    pModeStack = pTmp;
+    ModeStack *pTmp = m_pModeStack->pNext;
+    delete m_pModeStack;
+    m_pModeStack = pTmp;
 }
 
 // Two methodes for setting cursors: the first maps at the
@@ -348,11 +348,11 @@ long SwWrtShell::ResetSelect(const Point *,bool)
         //  after EndAction().
         {
             SwActContext aActContext(this);
-            bSelWrd = bSelLn = false;
+            m_bSelWrd = m_bSelLn = false;
             KillPams();
             ClearMark();
-            fnKillSel = &SwWrtShell::Ignore;
-            fnSetCrsr = &SwWrtShell::SetCrsr;
+            m_fnKillSel = &SwWrtShell::Ignore;
+            m_fnSetCrsr = &SwWrtShell::SetCrsr;
         }
 
         // After canceling of all selections an update of Attr-Controls
@@ -374,19 +374,19 @@ long SwWrtShell::Ignore(const Point *, bool ) {
 
 void SwWrtShell::SttSelect()
 {
-    if(bInSelect)
+    if(m_bInSelect)
         return;
     if(!HasMark())
         SetMark();
-    if( bBlockMode )
+    if( m_bBlockMode )
     {
         SwShellCrsr* pTmp = getShellCrsr( true );
         if( !pTmp->HasMark() )
             pTmp->SetMark();
     }
-    fnKillSel = &SwWrtShell::Ignore;
-    fnSetCrsr = &SwWrtShell::SetCrsr;
-    bInSelect = true;
+    m_fnKillSel = &SwWrtShell::Ignore;
+    m_fnSetCrsr = &SwWrtShell::SetCrsr;
+    m_bInSelect = true;
     Invalidate();
     SwTransferable::CreateSelection( *this );
 }
@@ -395,18 +395,18 @@ void SwWrtShell::SttSelect()
 
 void SwWrtShell::EndSelect()
 {
-    if(bInSelect && !bExtMode)
+    if(m_bInSelect && !m_bExtMode)
     {
-        bInSelect = false;
-        if (bAddMode)
+        m_bInSelect = false;
+        if (m_bAddMode)
         {
             AddLeaveSelect(0, false);
         }
         else
         {
             SttLeaveSelect(0, false);
-            fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
-            fnKillSel = &SwWrtShell::ResetSelect;
+            m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+            m_fnKillSel = &SwWrtShell::ResetSelect;
         }
     }
     SwWordCountWrapper *pWrdCnt = static_cast<SwWordCountWrapper*>(GetView().GetViewFrame()->GetChildWindow(SwWordCountWrapper::GetChildWindowId()));
@@ -435,7 +435,7 @@ long SwWrtShell::ExtSelWrd(const Point *pPt, bool )
 
     // check the direction of the selection with the new point
     bool bRet = false, bMoveCrsr = true, bToTop = false;
-    SwCrsrShell::SelectWord( &aStart );     // select the startword
+    SwCrsrShell::SelectWord( &m_aStart );     // select the startword
     SwCrsrShell::Push();                    // save the cursor
     SwCrsrShell::SetCrsr( *pPt );           // and check the direction
 
@@ -520,13 +520,13 @@ long SwWrtShell::ExtSelLn(const Point *pPt, bool )
 
 void SwWrtShell::EnterStdMode()
 {
-    if(bAddMode)
+    if(m_bAddMode)
         LeaveAddMode();
-    if(bBlockMode)
+    if(m_bBlockMode)
         LeaveBlockMode();
-    bBlockMode = false;
-    bExtMode = false;
-    bInSelect = false;
+    m_bBlockMode = false;
+    m_bExtMode = false;
+    m_bInSelect = false;
     if(IsSelFrmMode())
     {
         UnSelectFrm();
@@ -539,12 +539,12 @@ void SwWrtShell::EnterStdMode()
         // GetChgLnk().Call()
         {
             SwActContext aActContext(this);
-            bSelWrd = bSelLn = false;
+            m_bSelWrd = m_bSelLn = false;
             if( !IsRetainSelection() )
                 KillPams();
             ClearMark();
-            fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
-            fnKillSel = &SwWrtShell::ResetSelect;
+            m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+            m_fnKillSel = &SwWrtShell::ResetSelect;
         }
     }
     Invalidate();
@@ -555,21 +555,21 @@ void SwWrtShell::EnterStdMode()
 
 void SwWrtShell::EnterExtMode()
 {
-    if(bBlockMode)
+    if(m_bBlockMode)
     {
         LeaveBlockMode();
         KillPams();
         ClearMark();
     }
-    bExtMode = true;
-    bAddMode = false;
-    bBlockMode = false;
+    m_bExtMode = true;
+    m_bAddMode = false;
+    m_bBlockMode = false;
     SttSelect();
 }
 
 void SwWrtShell::LeaveExtMode()
 {
-    bExtMode = false;
+    m_bExtMode = false;
     EndSelect();
 }
 
@@ -578,7 +578,7 @@ void SwWrtShell::LeaveExtMode()
 
 long SwWrtShell::SttLeaveSelect(const Point *, bool )
 {
-    if(SwCrsrShell::HasSelection() && !IsSelTblCells() && bClearMark) {
+    if(SwCrsrShell::HasSelection() && !IsSelTblCells() && m_bClearMark) {
         return 0;
     }
     ClearMark();
@@ -600,13 +600,13 @@ long SwWrtShell::AddLeaveSelect(const Point *, bool )
 void SwWrtShell::EnterAddMode()
 {
     if(IsTableMode()) return;
-    if(bBlockMode)
+    if(m_bBlockMode)
         LeaveBlockMode();
-    fnKillSel = &SwWrtShell::Ignore;
-    fnSetCrsr = &SwWrtShell::SetCrsr;
-    bAddMode = true;
-    bBlockMode = false;
-    bExtMode = false;
+    m_fnKillSel = &SwWrtShell::Ignore;
+    m_fnSetCrsr = &SwWrtShell::SetCrsr;
+    m_bAddMode = true;
+    m_bBlockMode = false;
+    m_bExtMode = false;
     if(SwCrsrShell::HasSelection())
         CreateCrsr();
     Invalidate();
@@ -614,9 +614,9 @@ void SwWrtShell::EnterAddMode()
 
 void SwWrtShell::LeaveAddMode()
 {
-    fnKillSel = &SwWrtShell::ResetSelect;
-    fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
-    bAddMode = false;
+    m_fnKillSel = &SwWrtShell::ResetSelect;
+    m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+    m_bAddMode = false;
     Invalidate();
 }
 
@@ -624,16 +624,16 @@ void SwWrtShell::LeaveAddMode()
 
 void SwWrtShell::EnterBlockMode()
 {
-    bBlockMode = false;
+    m_bBlockMode = false;
     EnterStdMode();
-    bBlockMode = true;
+    m_bBlockMode = true;
     CrsrToBlockCrsr();
     Invalidate();
 }
 
 void SwWrtShell::LeaveBlockMode()
 {
-    bBlockMode = false;
+    m_bBlockMode = false;
     BlockCrsrToCrsr();
     EndSelect();
     Invalidate();
@@ -643,9 +643,9 @@ void SwWrtShell::LeaveBlockMode()
 
 void SwWrtShell::SetInsMode( bool bOn )
 {
-    bIns = bOn;
-    SwCrsrShell::SetOverwriteCrsr( !bIns );
-    const SfxBoolItem aTmp( SID_ATTR_INSERT, bIns );
+    m_bIns = bOn;
+    SwCrsrShell::SetOverwriteCrsr( !m_bIns );
+    const SfxBoolItem aTmp( SID_ATTR_INSERT, m_bIns );
     GetView().GetViewFrame()->GetBindings().SetState( aTmp );
     StartAction();
     EndAction();
@@ -663,7 +663,7 @@ void SwWrtShell::SetRedlineModeAndCheckInsMode( sal_uInt16 eMode )
 
 long SwWrtShell::BeginFrmDrag(const Point *pPt, bool bIsShift)
 {
-    fnDrag = &SwFEShell::Drag;
+    m_fnDrag = &SwFEShell::Drag;
     if(bStartDrag)
     {
         Point aTmp( nStartDragX, nStartDragY );
@@ -682,21 +682,21 @@ void SwWrtShell::EnterSelFrmMode(const Point *pPos)
         nStartDragY = pPos->Y();
         bStartDrag = true;
     }
-    bLayoutMode = true;
+    m_bLayoutMode = true;
     HideCrsr();
 
         // equal call of BeginDrag in the SwFEShell
-    fnDrag          = &SwWrtShell::BeginFrmDrag;
-    fnEndDrag       = &SwWrtShell::UpdateLayoutFrm;
+    m_fnDrag          = &SwWrtShell::BeginFrmDrag;
+    m_fnEndDrag       = &SwWrtShell::UpdateLayoutFrm;
     SwBaseShell::SetFrmMode( FLY_DRAG_START, this );
     Invalidate();
 }
 
 void SwWrtShell::LeaveSelFrmMode()
 {
-    fnDrag          = &SwWrtShell::BeginDrag;
-    fnEndDrag       = &SwWrtShell::DefaultEndDrag;
-    bLayoutMode = false;
+    m_fnDrag          = &SwWrtShell::BeginDrag;
+    m_fnEndDrag       = &SwWrtShell::DefaultEndDrag;
+    m_bLayoutMode = false;
     bStartDrag = false;
     Edit();
     SwBaseShell::SetFrmMode( FLY_DRAG_END, this );
@@ -715,7 +715,7 @@ IMPL_LINK( SwWrtShell, ExecFlyMac, void *, pFlyFmt )
     {
         const SvxMacro &rMac = rFmtMac.GetMacro(SW_EVENT_OBJECT_SELECT);
         if( IsFrmSelected() )
-            bLayoutMode = true;
+            m_bLayoutMode = true;
         CallChgLnk();
         ExecMacro( rMac );
     }
@@ -726,7 +726,7 @@ long SwWrtShell::UpdateLayoutFrm(const Point *pPt, bool )
 {
         // still a dummy
     SwFEShell::EndDrag( pPt, false );
-    fnDrag = &SwWrtShell::BeginFrmDrag;
+    m_fnDrag = &SwWrtShell::BeginFrmDrag;
     return 1;
 }
 
@@ -734,47 +734,47 @@ long SwWrtShell::UpdateLayoutFrm(const Point *pPt, bool )
 
 bool SwWrtShell::ToggleAddMode()
 {
-    bAddMode ? LeaveAddMode(): EnterAddMode();
+    m_bAddMode ? LeaveAddMode(): EnterAddMode();
     Invalidate();
-    return !bAddMode;
+    return !m_bAddMode;
 }
 
 bool SwWrtShell::ToggleBlockMode()
 {
-    bBlockMode ? LeaveBlockMode(): EnterBlockMode();
+    m_bBlockMode ? LeaveBlockMode(): EnterBlockMode();
     Invalidate();
-    return !bBlockMode;
+    return !m_bBlockMode;
 }
 
 bool SwWrtShell::ToggleExtMode()
 {
-    bExtMode ? LeaveExtMode() : EnterExtMode();
+    m_bExtMode ? LeaveExtMode() : EnterExtMode();
     Invalidate();
-    return !bExtMode;
+    return !m_bExtMode;
 }
 
 // Dragging in standard mode (Selecting of content)
 
 long SwWrtShell::BeginDrag(const Point * /*pPt*/, bool )
 {
-    if(bSelWrd)
+    if(m_bSelWrd)
     {
-        bInSelect = true;
+        m_bInSelect = true;
         if( !IsCrsrPtAtEnd() )
             SwapPam();
 
-        fnDrag = &SwWrtShell::ExtSelWrd;
-        fnSetCrsr = &SwWrtShell::Ignore;
+        m_fnDrag = &SwWrtShell::ExtSelWrd;
+        m_fnSetCrsr = &SwWrtShell::Ignore;
     }
-    else if(bSelLn)
+    else if(m_bSelLn)
     {
-        bInSelect = true;
-        fnDrag = &SwWrtShell::ExtSelLn;
-        fnSetCrsr = &SwWrtShell::Ignore;
+        m_bInSelect = true;
+        m_fnDrag = &SwWrtShell::ExtSelLn;
+        m_fnSetCrsr = &SwWrtShell::Ignore;
     }
     else
     {
-        fnDrag = &SwWrtShell::DefaultDrag;
+        m_fnDrag = &SwWrtShell::DefaultDrag;
         SttSelect();
     }
 
@@ -784,19 +784,19 @@ long SwWrtShell::BeginDrag(const Point * /*pPt*/, bool )
 long SwWrtShell::DefaultDrag(const Point *, bool )
 {
     if( IsSelTblCells() )
-        aSelTblLink.Call(this);
+        m_aSelTblLink.Call(this);
 
     return 1;
 }
 
 long SwWrtShell::DefaultEndDrag(const Point * /*pPt*/, bool )
 {
-    fnDrag = &SwWrtShell::BeginDrag;
+    m_fnDrag = &SwWrtShell::BeginDrag;
     if( IsExtSel() )
         LeaveExtSel();
 
     if( IsSelTblCells() )
-        aSelTblLink.Call(this);
+        m_aSelTblLink.Call(this);
     EndSelect();
     return 1;
 }
@@ -808,8 +808,8 @@ bool SwWrtShell::SelectTableRowCol( const Point& rPt, const Point* pEnd, bool bR
     SttSelect();
     if(SelTblRowCol( rPt, pEnd, bRowDrag ))
     {
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
-        fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
         return true;
     }
     return false;
@@ -821,8 +821,8 @@ bool SwWrtShell::SelectTableRow()
 {
     if ( SelTblRow() )
     {
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
-        fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
         return true;
     }
     return false;
@@ -832,8 +832,8 @@ bool SwWrtShell::SelectTableCol()
 {
     if ( SelTblCol() )
     {
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
-        fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
         return true;
     }
     return false;
@@ -843,8 +843,8 @@ bool SwWrtShell::SelectTableCell()
 {
     if ( SelTblBox() )
     {
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
-        fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
         return true;
     }
     return false;
@@ -947,8 +947,8 @@ bool SwWrtShell::SelectNextPrevHyperlink( bool bNext )
 
         // Set the function pointer for the canceling of the selection
         // set at cursor
-        fnKillSel = &SwWrtShell::ResetSelect;
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
         bCreateXSelection = true;
     }
     else if( bFrmSelected )
diff --git a/sw/source/uibase/wrtsh/wrtsh1.cxx b/sw/source/uibase/wrtsh/wrtsh1.cxx
index 8fdbd78..9490fb5 100644
--- a/sw/source/uibase/wrtsh/wrtsh1.cxx
+++ b/sw/source/uibase/wrtsh/wrtsh1.cxx
@@ -109,30 +109,30 @@ using namespace sw::mark;
 using namespace com::sun::star;
 
 #define COMMON_INI_LIST \
-        fnDrag(&SwWrtShell::BeginDrag),\
-        fnSetCrsr(&SwWrtShell::SetCrsr),\
-        fnEndDrag(&SwWrtShell::DefaultEndDrag),\
-        fnKillSel(&SwWrtShell::Ignore),\
-        pModeStack(0), \
-        ePageMove(MV_NO),\
-        pCrsrStack(0),  \
-        rView(rShell),\
-        aNavigationMgr(*this), \
-        bDestOnStack(false)
+        m_fnDrag(&SwWrtShell::BeginDrag),\
+        m_fnSetCrsr(&SwWrtShell::SetCrsr),\
+        m_fnEndDrag(&SwWrtShell::DefaultEndDrag),\
+        m_fnKillSel(&SwWrtShell::Ignore),\
+        m_pModeStack(0), \
+        m_ePageMove(MV_NO),\
+        m_pCrsrStack(0),  \
+        m_rView(rShell),\
+        m_aNavigationMgr(*this), \
+        m_bDestOnStack(false)
 
 #define BITFLD_INI_LIST \
-        bClearMark = \
-        bIns = true;\
-        bAddMode = \
-        bBlockMode = \
-        bExtMode = \
-        bInSelect = \
-        bCopy = \
-        bLayoutMode = \
-        bSelWrd = \
-        bSelLn = \
-        mbRetainSelection = false; \
-        bIsInClickToEdit = false;
+        m_bClearMark = \
+        m_bIns = true;\
+        m_bAddMode = \
+        m_bBlockMode = \
+        m_bExtMode = \
+        m_bInSelect = \
+        m_bCopy = \
+        m_bLayoutMode = \
+        m_bSelWrd = \
+        m_bSelLn = \
+        m_bRetainSelection = false; \
+        m_bIsInClickToEdit = false;
 
 static SvxAutoCorrect* lcl_IsAutoCorr()
 {
@@ -196,10 +196,10 @@ void SwWrtShell::Insert( const OUString &rStr )
 
     bool bStarted = false;
     bool bHasSel = HasSelection(),
-         bCallIns = bIns /*|| bHasSel*/;
+         bCallIns = m_bIns /*|| bHasSel*/;
     bool bDeleted = false;
 
-    if( bHasSel || ( !bIns && SelectHiddenRange() ) )
+    if( bHasSel || ( !m_bIns && SelectHiddenRange() ) )
     {
             // Only here parenthesizing, because the normal
             // insert is already in parentheses at Editshell.
@@ -935,7 +935,7 @@ void SwWrtShell::InsertFootnote(const OUString &rStr, bool bEndNote, bool bEdit
             Left(CRSR_SKIP_CHARS, false, 1, false );
             GotoFtnTxt();
         }
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     }
 }
 
@@ -950,7 +950,7 @@ void SwWrtShell::SplitNode( bool bAutoFmt, bool bCheckTableStart )
     {
         SwActContext aActContext(this);
 
-        rView.GetEditWin().FlushInBuffer();
+        m_rView.GetEditWin().FlushInBuffer();
         bool bHasSel = HasSelection();
         if( bHasSel )
         {
@@ -1493,7 +1493,7 @@ SwFrmFmt *SwWrtShell::GetTblStyle(const OUString &rFmtName)
 
 void SwWrtShell::addCurrentPosition() {
     SwPaM* pPaM = GetCrsr();
-    aNavigationMgr.addEntry(*pPaM->GetPoint());
+    m_aNavigationMgr.addEntry(*pPaM->GetPoint());
 }
 
 // Applying templates
@@ -1658,8 +1658,8 @@ bool SwWrtShell::Pop( bool bOldCrsr )
     bool bRet = SwCrsrShell::Pop( bOldCrsr );
     if( bRet && IsSelection() )
     {
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
-        fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
     }
     return bRet;
 }
diff --git a/sw/source/uibase/wrtsh/wrtsh2.cxx b/sw/source/uibase/wrtsh/wrtsh2.cxx
index 01fab7a..b909f05 100644
--- a/sw/source/uibase/wrtsh/wrtsh2.cxx
+++ b/sw/source/uibase/wrtsh/wrtsh2.cxx
@@ -326,7 +326,7 @@ void SwWrtShell::ClickToField( const SwField& rFld )
         EndAllAction();
     }
 
-    bIsInClickToEdit = true;
+    m_bIsInClickToEdit = true;
     switch( rFld.GetTyp()->Which() )
     {
     case RES_JUMPEDITFLD:
@@ -406,7 +406,7 @@ void SwWrtShell::ClickToField( const SwField& rFld )
         SAL_WARN_IF(rFld.IsClickable(), "sw", "unhandled clickable field!");
     }
 
-    bIsInClickToEdit = false;
+    m_bIsInClickToEdit = false;
 }
 
 void SwWrtShell::ClickToINetAttr( const SwFmtINetFmt& rItem, sal_uInt16 nFilter )
@@ -414,7 +414,7 @@ void SwWrtShell::ClickToINetAttr( const SwFmtINetFmt& rItem, sal_uInt16 nFilter
     if( rItem.GetValue().isEmpty() )
         return ;
 
-    bIsInClickToEdit = true;
+    m_bIsInClickToEdit = true;
 
     // At first run the possibly set ObjectSelect Macro
     const SvxMacro* pMac = rItem.GetMacro( SFX_EVENT_MOUSECLICK_OBJECT );
@@ -434,7 +434,7 @@ void SwWrtShell::ClickToINetAttr( const SwFmtINetFmt& rItem, sal_uInt16 nFilter
         const_cast<SwTxtINetFmt*>(pTxtAttr)->SetVisitedValid( true );
     }
 
-    bIsInClickToEdit = false;
+    m_bIsInClickToEdit = false;
 }
 
 bool SwWrtShell::ClickToINetGrf( const Point& rDocPt, sal_uInt16 nFilter )
diff --git a/sw/source/uibase/wrtsh/wrtsh3.cxx b/sw/source/uibase/wrtsh/wrtsh3.cxx
index cb265a2..252e523 100644
--- a/sw/source/uibase/wrtsh/wrtsh3.cxx
+++ b/sw/source/uibase/wrtsh/wrtsh3.cxx
@@ -43,7 +43,7 @@ extern bool g_bNoInterrupt;       // in swmodule.cxx
 bool SwWrtShell::MoveBookMark( BookMarkMove eFuncId, const ::sw::mark::IMark* const pMark)
 {
     addCurrentPosition();
-    (this->*fnKillSel)( 0, false );
+    (this->*m_fnKillSel)( 0, false );
 
     bool bRet = true;
     switch(eFuncId)
@@ -61,15 +61,15 @@ bool SwWrtShell::MoveBookMark( BookMarkMove eFuncId, const ::sw::mark::IMark* co
     }
     if( IsSelection() )
     {
-        fnKillSel = &SwWrtShell::ResetSelect;
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
     }
     return bRet;
 }
 
 bool SwWrtShell::GotoField( const SwFmtFld& rFld )
 {
-    (this->*fnKillSel)( 0, false );
+    (this->*m_fnKillSel)( 0, false );
 
     bool bRet = SwCrsrShell::GotoFld( rFld );
     if( bRet && IsSelFrmMode() )
@@ -80,8 +80,8 @@ bool SwWrtShell::GotoField( const SwFmtFld& rFld )
 
     if( IsSelection() )
     {
-        fnKillSel = &SwWrtShell::ResetSelect;
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
     }
 
     return bRet;
@@ -89,7 +89,7 @@ bool SwWrtShell::GotoField( const SwFmtFld& rFld )
 
 bool SwWrtShell::GotoFieldmark(::sw::mark::IFieldmark const * const pMark)
 {
-    (this->*fnKillSel)( 0, false );
+    (this->*m_fnKillSel)( 0, false );
     bool bRet = SwCrsrShell::GotoFieldmark(pMark);
     if( bRet && IsSelFrmMode() )
     {
@@ -98,8 +98,8 @@ bool SwWrtShell::GotoFieldmark(::sw::mark::IFieldmark const * const pMark)
     }
     if( IsSelection() )
     {
-        fnKillSel = &SwWrtShell::ResetSelect;
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
     }
     return bRet;
 }
diff --git a/sw/source/uibase/wrtsh/wrtundo.cxx b/sw/source/uibase/wrtsh/wrtundo.cxx
index 4ad06d4..6071417 100644
--- a/sw/source/uibase/wrtsh/wrtundo.cxx
+++ b/sw/source/uibase/wrtsh/wrtundo.cxx
@@ -70,8 +70,8 @@ void SwWrtShell::Do( DoType eDoType, sal_uInt16 nCnt )
 
         // Set the function pointer for canceling the selection at the
         // cursor position.
-        fnKillSel = &SwWrtShell::ResetSelect;
-        fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
+        m_fnKillSel = &SwWrtShell::ResetSelect;
+        m_fnSetCrsr = &SwWrtShell::SetCrsrKillSel;
         bCreateXSelection = true;
     }
     else if ( bFrmSelected )
commit 5e999832b6b317fba1da3c906167a8d76bbe7fef
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date:   Sat Mar 14 15:20:30 2015 +0100

    Use comphelper::containerToSequence()
    
    Change-Id: I0dcc582e9cb2b1021895e7962e1ec96195f1f844

diff --git a/writerfilter/source/dmapper/SettingsTable.cxx b/writerfilter/source/dmapper/SettingsTable.cxx
index 28945fb..fd04dce 100644
--- a/writerfilter/source/dmapper/SettingsTable.cxx
+++ b/writerfilter/source/dmapper/SettingsTable.cxx
@@ -17,17 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <stdio.h>
+#include <SettingsTable.hxx>
+
+#include <vector>
+
 #include <rtl/ustring.hxx>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/beans/XPropertyState.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/style/XStyle.hpp>
 #include <com/sun/star/style/XStyleFamiliesSupplier.hpp>
-#include <SettingsTable.hxx>
+#include <comphelper/sequence.hxx>
 #include <ooxml/resourceids.hxx>
 #include <ConversionHelper.hxx>
-
 #include "dmapperLoggers.hxx"
 #include "util.hxx"
 
@@ -82,7 +84,7 @@ struct SettingsTable_Impl
     bool                m_bMirrorMargin;
     uno::Sequence<beans::PropertyValue> m_pThemeFontLangProps;
 
-    uno::Sequence<beans::PropertyValue> m_pCompatSettings;
+    std::vector<beans::PropertyValue> m_aCompatSettings;
     uno::Sequence<beans::PropertyValue> m_pCurrentCompatSetting;
 
     SettingsTable_Impl( DomainMapper& rDMapper, const uno::Reference< lang::XMultiServiceFactory > & xTextFactory ) :
@@ -113,7 +115,6 @@ struct SettingsTable_Impl
     , m_bSplitPgBreakAndParaMark(false)
     , m_bMirrorMargin(false)
     , m_pThemeFontLangProps(3)
-    , m_pCompatSettings(0)
     , m_pCurrentCompatSetting(3)
     {}
 
@@ -275,10 +276,10 @@ void SettingsTable::lcl_sprm(Sprm& rSprm)
         {
             pProperties->resolve(*this);
 
-            sal_Int32 nLength = m_pImpl->m_pCompatSettings.getLength();
-            m_pImpl->m_pCompatSettings.realloc(nLength + 1);
-            m_pImpl->m_pCompatSettings[nLength].Name = "compatSetting";
-            m_pImpl->m_pCompatSettings[nLength].Value = uno::makeAny(m_pImpl->m_pCurrentCompatSetting);
+            beans::PropertyValue aValue;
+            aValue.Name = "compatSetting";
+            aValue.Value = uno::makeAny(m_pImpl->m_pCurrentCompatSetting);
+            m_pImpl->m_aCompatSettings.push_back(aValue);
         }
     }
     break;
@@ -301,10 +302,8 @@ void SettingsTable::lcl_entry(int /*pos*/, writerfilter::Reference<Properties>::
 {
     ref->resolve(*this);
 }
-//returns default TabStop in 1/100th mm
-
-
 
+//returns default TabStop in 1/100th mm
 int SettingsTable::GetDefaultTabStop() const
 {
     return ConversionHelper::convertTwipToMM100( m_pImpl->m_nDefaultTabStop );
@@ -372,7 +371,7 @@ uno::Sequence<beans::PropertyValue> SettingsTable::GetThemeFontLangProperties()
 
 uno::Sequence<beans::PropertyValue> SettingsTable::GetCompatSettings() const
 {
-    return m_pImpl->m_pCompatSettings;
+    return comphelper::containerToSequence(m_pImpl->m_aCompatSettings);
 }
 
 void SettingsTable::ApplyProperties(uno::Reference<text::XTextDocument> const& xDoc)
@@ -399,7 +398,6 @@ void SettingsTable::ApplyProperties(uno::Reference<text::XTextDocument> const& x
     }
 }
 
-
 }//namespace dmapper
 } //namespace writerfilter
 
commit d8bb2a9705be7a362d4efb6e7e52cd9cb0eaf46d
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date:   Sat Mar 14 14:15:34 2015 +0100

    tdf#90003 Revert "SwTxtFormatter::NewPortion: fix lost SwFlyPortion"
    
    This reverts commit 25c50ff9fb0f277da9bc164d8244a774ef1ebba4. The
    original commit fixed a corner-case, but also broke a much more frequent
    use case. Revert till we have a better solution for the corner-case.
    
    Conflicts:
    	sw/qa/extras/inc/swmodeltestbase.hxx
    	sw/qa/extras/uiwriter/uiwriter.cxx
    
    Change-Id: I0f90459e9bc372eeba18bf81c5d1dfcccbe21753

diff --git a/sw/qa/extras/uiwriter/data/fdo87005.odt b/sw/qa/extras/uiwriter/data/fdo87005.odt
deleted file mode 100644
index 54d7119..0000000
Binary files a/sw/qa/extras/uiwriter/data/fdo87005.odt and /dev/null differ
diff --git a/sw/qa/extras/uiwriter/data/tdf90003.odt b/sw/qa/extras/uiwriter/data/tdf90003.odt
new file mode 100644
index 0000000..280c254
Binary files /dev/null and b/sw/qa/extras/uiwriter/data/tdf90003.odt differ
diff --git a/sw/qa/extras/uiwriter/uiwriter.cxx b/sw/qa/extras/uiwriter/uiwriter.cxx
index d76a27a..31b9bdf 100644
--- a/sw/qa/extras/uiwriter/uiwriter.cxx
+++ b/sw/qa/extras/uiwriter/uiwriter.cxx
@@ -72,7 +72,6 @@ public:
     void testChineseConversionSimplifiedToTraditional();
     void testFdo85554();
     void testAutoCorr();
-    void testFdo87005();
     void testMergeDoc();
     void testCreatePortions();
     void testBookmarkUndo();
@@ -80,6 +79,7 @@ public:
     void testFdo87448();
     void testTdf68183();
     void testCp1000115();
+    void testTdf90003();
 
     CPPUNIT_TEST_SUITE(SwUiWriterTest);
     CPPUNIT_TEST(testReplaceForward);
@@ -104,7 +104,6 @@ public:
     CPPUNIT_TEST(testChineseConversionSimplifiedToTraditional);
     CPPUNIT_TEST(testFdo85554);
     CPPUNIT_TEST(testAutoCorr);
-    CPPUNIT_TEST(testFdo87005);
     CPPUNIT_TEST(testMergeDoc);
     CPPUNIT_TEST(testCreatePortions);
     CPPUNIT_TEST(testBookmarkUndo);
@@ -112,6 +111,7 @@ public:
     CPPUNIT_TEST(testFdo87448);
     CPPUNIT_TEST(testTdf68183);
     CPPUNIT_TEST(testCp1000115);
+    CPPUNIT_TEST(testTdf90003);
 
     CPPUNIT_TEST_SUITE_END();
 
@@ -648,15 +648,6 @@ void SwUiWriterTest::testAutoCorr()
     CPPUNIT_ASSERT_EQUAL(sal_Int32(3), xTable->getColumns()->getCount());
 }
 
-void SwUiWriterTest::testFdo87005()
-{
-    createDoc("fdo87005.odt");
-    xmlDocPtr pXmlDoc = parseLayoutDump();
-    CPPUNIT_ASSERT(pXmlDoc);
-    // This was 1, no SwFlyPortion was created for the second fly.
-    assertXPath(pXmlDoc, "//Special[@nType='POR_FLY']", 2);
-}
-
 void SwUiWriterTest::testMergeDoc()
 {
     SwDoc* const pDoc1(createDoc("merge-change1.odt"));
@@ -846,6 +837,16 @@ void SwUiWriterTest::testCp1000115()
     xmlXPathFreeObject(pXmlObj);
 }
 
+void SwUiWriterTest::testTdf90003()
+{
+    createDoc("tdf90003.odt");
+    xmlDocPtr pXmlDoc = parseLayoutDump();
+    CPPUNIT_ASSERT(pXmlDoc);
+    // This was 1: an unexpected fly portion was created, resulting in too
+    // large x position for the empty paragraph marker.
+    assertXPath(pXmlDoc, "//Special[@nType='POR_FLY']", 0);
+}
+
 CPPUNIT_TEST_SUITE_REGISTRATION(SwUiWriterTest);
 CPPUNIT_PLUGIN_IMPLEMENT();
 
diff --git a/sw/source/core/text/itrform2.cxx b/sw/source/core/text/itrform2.cxx
index 6cdbf9c..425a79d 100644
--- a/sw/source/core/text/itrform2.cxx
+++ b/sw/source/core/text/itrform2.cxx
@@ -1303,13 +1303,6 @@ SwLinePortion *SwTxtFormatter::NewPortion( SwTxtFormatInfo &rInf )
             {
                 rInf.SetFull(true);
                 CalcFlyWidth( rInf );
-
-                // In case we have no portion to return, but CalcFlyWidth()
-                // created a fly portion, then return that. Otherwise such a
-                // fly portion would not be ever inserted to the layout.
-                if (!pPor)
-                    pPor = rInf.GetFly();
-
                 return pPor;
             }
             cChar = rInf.GetChar( rInf.GetIdx() );


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/uibase/inc/wrtsh.hxx b/sw/source/uibase/inc/wrtsh.hxx
index 2e7c4cd..7880165 100644
--- a/sw/source/uibase/inc/wrtsh.hxx
+++ b/sw/source/uibase/inc/wrtsh.hxx
@@ -94,19 +94,19 @@ private:
 
     typedef long (SwWrtShell::*SELECTFUNC)(const Point *, bool bProp );
 
-    SELECTFUNC  fnDrag;
-    SELECTFUNC  fnSetCrsr;
-    SELECTFUNC  fnEndDrag;
-    SELECTFUNC  fnKillSel;
+    SELECTFUNC  m_fnDrag;
+    SELECTFUNC  m_fnSetCrsr;
+    SELECTFUNC  m_fnEndDrag;
+    SELECTFUNC  m_fnKillSel;
 
 public:
 
     using SwEditShell::Insert;
 
-    long SetCursor    (const Point* pPt, bool bProp) { return (this->*fnSetCrsr)(pPt, bProp); }
-    long Drag         (const Point* pPt, bool bProp) { return (this->*fnDrag)(pPt, bProp); }
-    long EndDrag      (const Point* pPt, bool bProp) { return (this->*fnEndDrag)(pPt, bProp); }
-    long KillSelection(const Point* pPt, bool bProp) { return (this->*fnKillSel)(pPt, bProp); }
+    long SetCursor    (const Point* pPt, bool bProp) { return (this->*m_fnSetCrsr)(pPt, bProp); }
+    long Drag         (const Point* pPt, bool bProp) { return (this->*m_fnDrag)(pPt, bProp); }
+    long EndDrag      (const Point* pPt, bool bProp) { return (this->*m_fnEndDrag)(pPt, bProp); }
+    long KillSelection(const Point* pPt, bool bProp) { return (this->*m_fnKillSel)(pPt, bProp); }
 
     // reset all selections
     long ResetSelect( const Point *, bool );
@@ -115,45 +115,45 @@ public:
     inline void ResetCursorStack();
     SelectionType   GetSelectionType() const;
 
-    bool    IsModePushed() const { return 0 != pModeStack; }
+    bool    IsModePushed() const { return 0 != m_pModeStack; }
     void    PushMode();
     void    PopMode();
 
     void    SttSelect();
     void    EndSelect();
-    bool    IsInSelect() const { return bInSelect; }
-    void    SetInSelect(bool bSel = true) { bInSelect = bSel; }
+    bool    IsInSelect() const { return m_bInSelect; }
+    void    SetInSelect(bool bSel = true) { m_bInSelect = bSel; }
         // is there a text- or frameselection?
     bool    HasSelection() const { return SwCrsrShell::HasSelection() ||
                                         IsMultiSelection() || IsSelFrmMode() || IsObjSelected(); }
     bool     Pop( bool bOldCrsr = true );
 
     void    EnterStdMode();
-    bool    IsStdMode() const { return !bExtMode && !bAddMode && !bBlockMode; }
+    bool    IsStdMode() const { return !m_bExtMode && !m_bAddMode && !m_bBlockMode; }
 
     void    EnterExtMode();
     void    LeaveExtMode();
     bool    ToggleExtMode();
-    bool    IsExtMode() const { return bExtMode; }
+    bool    IsExtMode() const { return m_bExtMode; }
 
     void    EnterAddMode();
     void    LeaveAddMode();
     bool    ToggleAddMode();
-    bool    IsAddMode() const { return bAddMode; }
+    bool    IsAddMode() const { return m_bAddMode; }
 
     void    EnterBlockMode();
     void    LeaveBlockMode();
     bool    ToggleBlockMode();
-    bool    IsBlockMode() const { return bBlockMode; }
+    bool    IsBlockMode() const { return m_bBlockMode; }
 
     void    SetInsMode( bool bOn = true );
-    void    ToggleInsMode() { SetInsMode( !bIns ); }
-    bool    IsInsMode() const { return bIns; }
+    void    ToggleInsMode() { SetInsMode( !m_bIns ); }
+    bool    IsInsMode() const { return m_bIns; }
     void    SetRedlineModeAndCheckInsMode( sal_uInt16 eMode );
 
     void    EnterSelFrmMode(const Point *pStartDrag = 0);
     void    LeaveSelFrmMode();
-    bool    IsSelFrmMode() const { return bLayoutMode; }
+    bool    IsSelFrmMode() const { return m_bLayoutMode; }
         // reset selection of frames
     void    UnSelectFrm();
 
@@ -164,9 +164,9 @@ public:
     inline void EndSelTblCells();
 
     // leave per word or per line selection mode. Is usually called in MB-Up.
-    bool    IsExtSel() const { return bSelWrd || bSelLn; }
+    bool    IsExtSel() const { return m_bSelWrd || m_bSelLn; }
 
     // query whether the active fnDrag pointer is set to BeginDrag
     // is needed for MouseMove to work around bugs 55592/55931
     inline bool Is_FnDragEQBeginDrag() const;
 
@@ -254,8 +254,8 @@ typedef bool (SwWrtShell:: *FNSimpleMove)();
     void    NoEdit(bool bHideCrsr = true);
     void    Edit();
 
-    bool IsRetainSelection() const { return mbRetainSelection; }
-    void SetRetainSelection( bool bRet ) { mbRetainSelection = bRet; }
+    bool IsRetainSelection() const { return m_bRetainSelection; }
+    void SetRetainSelection( bool bRet ) { m_bRetainSelection = bRet; }
 
     // change current data base and notify
     void ChgDBData(const SwDBData& SwDBData);
@@ -412,8 +412,8 @@ typedef bool (SwWrtShell:: *FNSimpleMove)();
     bool SelectNextPrevHyperlink( bool bNext = true );
 
     // determine corresponding SwView
-    const SwView&       GetView() const { return rView; }
-    SwView&             GetView() { return rView; }
+    const SwView&       GetView() const { return m_rView; }
+    SwView&             GetView() { return m_rView; }
 
     // Because nobody else is doing it, here is a ExecMacro()
     void ExecMacro( const SvxMacro& rMacro, OUString* pRet = 0, SbxArray* pArgs = 0 );
@@ -455,7 +455,7 @@ typedef bool (SwWrtShell:: *FNSimpleMove)();
 
     OUString GetSelDescr() const;
 
-    SwNavigationMgr& GetNavigationMgr() { return aNavigationMgr; }
+    SwNavigationMgr& GetNavigationMgr() { return m_aNavigationMgr; }
 
     void addCurrentPosition();
     bool GotoFly( const OUString& rName, FlyCntType eType = FLYCNTTYPE_ALL,
@@ -493,7 +493,7 @@ private:
             bExt(_bExt),
             bIns(_bIns)
              {}
-    } *pModeStack;
+    } *m_pModeStack;
 
     // carry cursor along when PageUp / -Down
     enum PageMove
@@ -501,7 +501,7 @@ private:
         MV_NO,
         MV_PAGE_UP,
         MV_PAGE_DOWN
-    }  ePageMove;
+    }  m_ePageMove;
 
     struct CrsrStack
     {
@@ -522,14 +522,14 @@ private:
 
         }
 
-    } *pCrsrStack;
+    } *m_pCrsrStack;
 
-    SwView  &rView;
-    SwNavigationMgr aNavigationMgr;
+    SwView  &m_rView;
+    SwNavigationMgr m_aNavigationMgr;
 
-    Point   aDest;
-    bool    bDestOnStack;
-    bool    HasCrsrStack() const { return 0 != pCrsrStack; }
+    Point   m_aDest;
+    bool    m_bDestOnStack;
+    bool    HasCrsrStack() const { return 0 != m_pCrsrStack; }
     SAL_DLLPRIVATE bool  PushCrsr(SwTwips lOffset, bool bSelect);
     SAL_DLLPRIVATE bool  PopCrsr(bool bUpdate, bool bSelect = false);
 
@@ -547,21 +547,21 @@ private:
     SAL_DLLPRIVATE bool _BwdPara();
 
         // selections
-    bool    bIns            :1;
-    bool    bInSelect       :1;
-    bool    bExtMode        :1;
-    bool    bAddMode        :1;
-    bool    bBlockMode      :1;
-    bool    bLayoutMode     :1;
-    bool    bCopy           :1;
-    bool    bSelWrd         :1;
-    bool    bSelLn          :1;
-    bool    bIsInClickToEdit:1;
-    bool    bClearMark      :1;     // don't delete selection for ChartAutoPilot
-    bool    mbRetainSelection :1; // Do not remove selections
-
-    Point   aStart;
-    Link    aSelTblLink;
+    bool    m_bIns            :1;
+    bool    m_bInSelect       :1;
+    bool    m_bExtMode        :1;
+    bool    m_bAddMode        :1;
+    bool    m_bBlockMode      :1;
+    bool    m_bLayoutMode     :1;
+    bool    m_bCopy           :1;
+    bool    m_bSelWrd         :1;
+    bool    m_bSelLn          :1;
+    bool    m_bIsInClickToEdit:1;
+    bool    m_bClearMark      :1;     // don't delete selection for ChartAutoPilot
+    bool    m_bRetainSelection :1; // Do not remove selections
+
+    Point   m_aStart;
+    Link    m_aSelTblLink;
 
     // resets the cursor stack after movement by PageUp/-Down
     SAL_DLLPRIVATE void  _ResetCursorStack();
@@ -593,7 +593,7 @@ private:
     SAL_DLLPRIVATE long  AddLeaveSelect(const Point *, bool bProp=false );
     SAL_DLLPRIVATE long  Ignore(const Point *, bool bProp=false );
 
-    SAL_DLLPRIVATE void  LeaveExtSel() { bSelWrd = bSelLn = false;}
+    SAL_DLLPRIVATE void  LeaveExtSel() { m_bSelWrd = m_bSelLn = false;}
 
     SAL_DLLPRIVATE bool  GoStart(bool KeepArea = false, bool * = 0,
             bool bSelect = false, bool bDontMoveRegion = false);
@@ -619,24 +619,24 @@ inline void SwWrtShell::ResetCursorStack()
 inline void SwWrtShell::SelTblCells(const Link &rLink, bool bMark )
 {
     SetSelTblCells( true );
-    bClearMark = bMark;
-    aSelTblLink = rLink;
+    m_bClearMark = bMark;
+    m_aSelTblLink = rLink;
 }
 inline void SwWrtShell::EndSelTblCells()
 {
     SetSelTblCells( false );
-    bClearMark = true;
+    m_bClearMark = true;
 }
 
-inline bool SwWrtShell::IsInClickToEdit() const { return bIsInClickToEdit; }
+inline bool SwWrtShell::IsInClickToEdit() const { return m_bIsInClickToEdit; }
 
 inline bool SwWrtShell::Is_FnDragEQBeginDrag() const
 {
 #ifdef __GNUC__
     SELECTFUNC  fnTmp = &SwWrtShell::BeginDrag;
-    return fnDrag == fnTmp;
+    return m_fnDrag == fnTmp;
 #else
-    return fnDrag == &SwWrtShell::BeginDrag;
+    return m_fnDrag == &SwWrtShell::BeginDrag;
 #endif
 }
 
@@ -164,9 +164,9 @@ public:
 
-    // query whether the active fnDrag pointer is set to BeginDrag
+    // query whether the active m_fnDrag pointer is set to BeginDrag
     // is needed for MouseMove to work around bugs 55592/55931
     inline bool Is_FnDragEQBeginDrag() const;
diff --git a/sw/source/uibase/wrtsh/move.cxx b/sw/source/uibase/wrtsh/move.cxx
index 24ab2c4..a407b33 100644
--- a/sw/source/uibase/wrtsh/move.cxx
+++ b/sw/source/uibase/wrtsh/move.cxx
@@ -74,7 +74,7 @@ void SwWrtShell::MoveCrsr( bool bWithSelect )
     else
     {
         EndSelect();
-        (this->*fnKillSel)( 0, false );
+        (this->*m_fnKillSel)( 0, false );
     }
 }
 
@@ -100,7 +100,7 @@ bool SwWrtShell::Left( sal_uInt16 nMode, bool bSelect,
     {
         Point aTmp( VisArea().Pos() );
         aTmp.X() -= VisArea().Width() * nReadOnlyScrollOfst / 100;
-        rView.SetVisArea( aTmp );
+        m_rView.SetVisArea( aTmp );
         return true;
     }
     else
@@ -117,8 +117,8 @@ bool SwWrtShell::Right( sal_uInt16 nMode, bool bSelect,
     {
         Point aTmp( VisArea().Pos() );
         aTmp.X() += VisArea().Width() * nReadOnlyScrollOfst / 100;
-        aTmp.X() = rView.SetHScrollMax( aTmp.X() );
-        rView.SetVisArea( aTmp );
+        aTmp.X() = m_rView.SetHScrollMax( aTmp.X() );
+        m_rView.SetVisArea( aTmp );
         return true;
     }
     else
@@ -134,7 +134,7 @@ bool SwWrtShell::Up( bool bSelect, sal_uInt16 nCount, bool bBasicCall )
     {
         Point aTmp( VisArea().Pos() );
         aTmp.Y() -= VisArea().Height() * nReadOnlyScrollOfst / 100;
-        rView.SetVisArea( aTmp );
+        m_rView.SetVisArea( aTmp );
         return true;
     }
 
@@ -148,8 +148,8 @@ bool SwWrtShell::Down( bool bSelect, sal_uInt16 nCount, bool bBasicCall )
     {
         Point aTmp( VisArea().Pos() );
         aTmp.Y() += VisArea().Height() * nReadOnlyScrollOfst / 100;
-        aTmp.Y() = rView.SetVScrollMax( aTmp.Y() );
-        rView.SetVisArea( aTmp );
+        aTmp.Y() = m_rView.SetVScrollMax( aTmp.Y() );
+        m_rView.SetVisArea( aTmp );
         return true;
     }
 
@@ -163,7 +163,7 @@ bool SwWrtShell::LeftMargin( bool bSelect, bool bBasicCall )
     {
         Point aTmp( VisArea().Pos() );
         aTmp.X() = DOCUMENTBORDER;
-        rView.SetVisArea( aTmp );
+        m_rView.SetVisArea( aTmp );
         return true;
     }
     else
@@ -181,7 +181,7 @@ bool SwWrtShell::RightMargin( bool bSelect, bool bBasicCall  )
         aTmp.X() = GetDocSize().Width() - VisArea().Width() + DOCUMENTBORDER;
         if( DOCUMENTBORDER > aTmp.X() )
             aTmp.X() = DOCUMENTBORDER;
-        rView.SetVisArea( aTmp );
+        m_rView.SetVisArea( aTmp );
         return true;
     }
     else
@@ -197,7 +197,7 @@ bool SwWrtShell::GoStart( bool bKeepArea, bool *pMoveTable,
     if ( IsCrsrInTbl() )
     {
         const bool bBoxSelection = HasBoxSelection();
-        if( !bBlockMode )
+        if( !m_bBlockMode )
         {
             if ( !bSelect )
                 EnterStdMode();
@@ -230,7 +230,7 @@ bool SwWrtShell::GoStart( bool bKeepArea, bool *pMoveTable,
         }
     }
 
-    if( !bBlockMode )
+    if( !m_bBlockMode )
     {
         if ( !bSelect )
             EnterStdMode();
@@ -396,9 +396,9 @@ bool SwWrtShell::PushCrsr(SwTwips lOffset, bool bSelect)
     bool bDiff = false;
     SwRect aOldRect( GetCharRect() ), aTmpArea( VisArea() );
 
     // bDestOnStack indicates if I could not set the coursor at the current
     // position, because in this region is no content.
-    if( !bDestOnStack )
+    if( !m_bDestOnStack )
     {
         Point aPt( aOldRect.Center() );
 
@@ -408,12 +408,12 @@ bool SwWrtShell::PushCrsr(SwTwips lOffset, bool bSelect)
             aPt.Y() = aTmpArea.Top() + aTmpArea.Height() / 2;
 
         aPt.Y() += lOffset;
-        aDest = GetCntntPos(aPt,lOffset > 0);
-        aDest.X() = aPt.X();
-        bDestOnStack = true;
+        m_aDest = GetCntntPos(aPt,lOffset > 0);
+        m_aDest.X() = aPt.X();
+        m_bDestOnStack = true;
     }
 
     // If we had a frame selection, it must be removed after the fnSetCrsr
     // and we have to remember the position on the stack to return to it later.
     bool bIsFrmSel = false;
 
@@ -422,7 +422,7 @@ bool SwWrtShell::PushCrsr(SwTwips lOffset, bool bSelect)
     //position is longer on the stack.
     //The new visible region is to be determined beforehand.
     aTmpArea.Pos().Y() += lOffset;
-    if( aTmpArea.IsInside(aDest) )
+    if( aTmpArea.IsInside(m_aDest) )
     {
         if( bSelect )
             SttSelect();
@@ -446,7 +446,7 @@ bool SwWrtShell::PushCrsr(SwTwips lOffset, bool bSelect)
             CallChgLnk();
         }
 
-        (this->*fnSetCrsr)( &aDest, true );
+        (this->*m_fnSetCrsr)( &m_aDest, true );
 
         bDiff = aOldRect != GetCharRect();
 
@@ -458,41 +458,41 @@ bool SwWrtShell::PushCrsr(SwTwips lOffset, bool bSelect)
         }
 
             // reset Dest. SPoint Flags
-        bDestOnStack = false;
+        m_bDestOnStack = false;
     }
 
     // Position into the stack; bDiff indicates if there is a
     // difference between the old and the new cursor position.
-    pCrsrStack = new CrsrStack( bDiff, bIsFrmSel, aOldRect.Center(),
-                                lOffset, pCrsrStack );
-    return !bDestOnStack && bDiff;
+    m_pCrsrStack = new CrsrStack( bDiff, bIsFrmSel, aOldRect.Center(),
+                                lOffset, m_pCrsrStack );
+    return !m_bDestOnStack && bDiff;
 }
 
 bool SwWrtShell::PopCrsr(bool bUpdate, bool bSelect)
 {
-    if( 0 == pCrsrStack)
+    if( 0 == m_pCrsrStack)
         return false;
 
-    const bool bValidPos = pCrsrStack->bValidCurPos;
+    const bool bValidPos = m_pCrsrStack->bValidCurPos;
     if( bUpdate && bValidPos )
     {
             // If a predecessor is on the stack,
             // use the flag for a valid position.
         SwRect aTmpArea(VisArea());
-        aTmpArea.Pos().Y() -= pCrsrStack->lOffset;
-        if( aTmpArea.IsInside( pCrsrStack->aDocPos ) )
+        aTmpArea.Pos().Y() -= m_pCrsrStack->lOffset;
+        if( aTmpArea.IsInside( m_pCrsrStack->aDocPos ) )
         {
             if( bSelect )
                 SttSelect();
             else
                 EndSelect();
 
-            (this->*fnSetCrsr)(&pCrsrStack->aDocPos, !pCrsrStack->bIsFrmSel);
-            if( pCrsrStack->bIsFrmSel && IsObjSelectable(pCrsrStack->aDocPos))
+            (this->*m_fnSetCrsr)(&m_pCrsrStack->aDocPos, !m_pCrsrStack->bIsFrmSel);
+            if( m_pCrsrStack->bIsFrmSel && IsObjSelectable(m_pCrsrStack->aDocPos))
             {
                 HideCrsr();
-                SelectObj( pCrsrStack->aDocPos );
-                EnterSelFrmMode( &pCrsrStack->aDocPos );
+                SelectObj( m_pCrsrStack->aDocPos );
+                EnterSelFrmMode( &m_pCrsrStack->aDocPos );
             }
         }
             // If a discrepancy between the visible range and the
@@ -504,13 +504,13 @@ bool SwWrtShell::PopCrsr(bool bUpdate, bool bSelect)
             return false;
         }
     }
-    CrsrStack *pTmp = pCrsrStack;
-    pCrsrStack = pCrsrStack->pNext;
+    CrsrStack *pTmp = m_pCrsrStack;
+    m_pCrsrStack = m_pCrsrStack->pNext;
     delete pTmp;
-    if( 0 == pCrsrStack )
+    if( 0 == m_pCrsrStack )
     {
-        ePageMove = MV_NO;
-        bDestOnStack = false;
+        m_ePageMove = MV_NO;
+        m_bDestOnStack = false;
     }
     return bValidPos;
 }
@@ -520,14 +520,14 @@ bool SwWrtShell::PopCrsr(bool bUpdate, bool bSelect)
 
 void SwWrtShell::_ResetCursorStack()
 {
-    while(pCrsrStack)
+    while(m_pCrsrStack)
     {
-        CrsrStack* const pTmp = pCrsrStack->pNext;
-        delete pCrsrStack;
-        pCrsrStack = pTmp;
+        CrsrStack* const pTmp = m_pCrsrStack->pNext;
+        delete m_pCrsrStack;
+        m_pCrsrStack = pTmp;
     }
-    ePageMove = MV_NO;
-    bDestOnStack = false;
+    m_ePageMove = MV_NO;
+    m_bDestOnStack = false;
 }
 /**
     if no stack exists --> cancel selection
@@ -554,11 +554,11 @@ bool SwWrtShell::PageCrsr(SwTwips lOffset, bool bSelect)
         // SwViewShell::StartAction();
     PageMove eDir = lOffset > 0? MV_PAGE_DOWN: MV_PAGE_UP;
         // Change of direction and stack present
-    if( eDir != ePageMove && ePageMove != MV_NO && PopCrsr( true, bSelect ))
+    if( eDir != m_ePageMove && m_ePageMove != MV_NO && PopCrsr( true, bSelect ))
         return true;
 
     const bool bRet = PushCrsr(lOffset, bSelect);
-    ePageMove = eDir;
+    m_ePageMove = eDir;
     return bRet;
 }
 
@@ -583,7 +583,7 @@ bool SwWrtShell::GotoMark( const ::sw::mark::IMark* const pMark, bool bSelect, b
     SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwCrsrShell::GotoMark( pMark, bStart );
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
 }
 
@@ -592,7 +592,7 @@ bool SwWrtShell::GotoFly( const OUString& rName, FlyCntType eType, bool bSelFram
     SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwFEShell::GotoFly(rName, eType, bSelFrame);
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
 }
 
@@ -601,7 +601,7 @@ bool SwWrtShell::GotoINetAttr( const SwTxtINetFmt& rAttr )
     SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwCrsrShell::GotoINetAttr(rAttr);
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
 }
 
@@ -616,7 +616,7 @@ bool SwWrtShell::GotoOutline( const OUString& rName )
     SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwCrsrShell::GotoOutline (rName);
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
 }
 
@@ -625,7 +625,7 @@ bool SwWrtShell::GotoRegion( const OUString& rName )
     SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwCrsrShell::GotoRegion (rName);
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
  }
 
@@ -635,7 +635,7 @@ bool SwWrtShell::GotoRefMark( const OUString& rRefMark, sal_uInt16 nSubType,
     SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwCrsrShell::GotoRefMark(rRefMark, nSubType, nSeqNo);
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
 }
 
@@ -644,7 +644,7 @@ bool SwWrtShell::GotoNextTOXBase( const OUString* pName )
     SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwCrsrShell::GotoNextTOXBase(pName);
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
 }
 
@@ -653,7 +653,7 @@ bool SwWrtShell::GotoTable( const OUString& rName )
    SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwCrsrShell::GotoTable(rName);
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
 }
 
@@ -661,7 +661,7 @@ bool SwWrtShell::GotoFld( const SwFmtFld& rFld ) {
     SwPosition aPos = *GetCrsr()->GetPoint();
     bool bRet = SwCrsrShell::GotoFld(rFld);
     if (bRet)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return bRet;
 }
 
@@ -669,7 +669,7 @@ const SwRangeRedline* SwWrtShell::GotoRedline( sal_uInt16 nArrPos, bool bSelect
     SwPosition aPos = *GetCrsr()->GetPoint();
     const SwRangeRedline *pRedline = SwCrsrShell::GotoRedline(nArrPos, bSelect);
     if (pRedline)
-        aNavigationMgr.addEntry(aPos);
+        m_aNavigationMgr.addEntry(aPos);
     return pRedline;
 }
 
@@ -396,9 +396,9 @@ bool SwWrtShell::PushCrsr(SwTwips lOffset, bool bSelect)
     SwRect aOldRect( GetCharRect() ), aTmpArea( VisArea() );
 
-    // bDestOnStack indicates if I could not set the coursor at the current
+    // m_bDestOnStack indicates if I could not set the coursor at the current
     // position, because in this region is no content.
@@ -408,12 +408,12 @@ bool SwWrtShell::PushCrsr(SwTwips lOffset, bool bSelect)
     }
 
-    // If we had a frame selection, it must be removed after the fnSetCrsr
+    // If we had a frame selection, it must be removed after the m_fnSetCrsr
     // and we have to remember the position on the stack to return to it later.
     bool bIsFrmSel = false;